@@ -19,7 +19,6 @@ import (
 	"github.com/jonboulle/clockwork"
 	"github.com/pkg/errors"
 	"github.com/tektoncd/pipeline/pkg/client/clientset/versioned"
-	versionedResource "github.com/tektoncd/pipeline/pkg/client/resource/clientset/versioned"
 	versionedTriggers "github.com/tektoncd/triggers/pkg/client/clientset/versioned"
 	"k8s.io/client-go/dynamic"
 	k8s "k8s.io/client-go/kubernetes"
@@ -63,15 +62,6 @@ func (p *TektonParams) triggersClient(config *rest.Config) (versionedTriggers.In
 	return cs, nil
 }
 
-func (p *TektonParams) resourceClient(config *rest.Config) (versionedResource.Interface, error) {
-	cs, err := versionedResource.NewForConfig(config)
-	if err != nil {
-		return nil, err
-	}
-
-	return cs, nil
-}
-
 // Set kube client based on config
 func (p *TektonParams) kubeClient(config *rest.Config) (k8s.Interface, error) {
 	k8scs, err := k8s.NewForConfig(config)
@@ -127,11 +117,6 @@ func (p *TektonParams) Clients(cfg ...*rest.Config) (*Clients, error) {
 		return nil, err
 	}
 
-	resource, err := p.resourceClient(config)
-	if err != nil {
-		return nil, err
-	}
-
 	triggers, err := p.triggersClient(config)
 	if err != nil {
 		return nil, err
@@ -150,7 +135,6 @@ func (p *TektonParams) Clients(cfg ...*rest.Config) (*Clients, error) {
 	p.clients = &Clients{
 		Tekton:   tekton,
 		Kube:     kube,
-		Resource: resource,
 		Triggers: triggers,
 		Dynamic:  dynamic,
 	}
