@@ -19,14 +19,16 @@ import (
 	"strings"
 
 	"github.com/spf13/cobra"
+	"github.com/tektoncd/cli/pkg/actions"
 	"github.com/tektoncd/cli/pkg/cli"
-	cthelper "github.com/tektoncd/cli/pkg/clustertask"
+	"github.com/tektoncd/cli/pkg/clustertask"
 	"github.com/tektoncd/cli/pkg/cmd/taskrun"
 	"github.com/tektoncd/cli/pkg/flags"
 	"github.com/tektoncd/cli/pkg/formatted"
 	"github.com/tektoncd/cli/pkg/options"
-	thelper "github.com/tektoncd/cli/pkg/task"
-	trlist "github.com/tektoncd/cli/pkg/taskrun/list"
+	"github.com/tektoncd/cli/pkg/task"
+	taskrunpkg "github.com/tektoncd/cli/pkg/taskrun"
+	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1beta1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
@@ -37,7 +39,8 @@ func nameArg(args []string, p cli.Params) error {
 			return err
 		}
 		name := args[0]
-		if _, err = cthelper.Get(c, name, metav1.GetOptions{}); err != nil {
+		var clustertask *v1beta1.ClusterTask
+		if err = actions.GetV1(clustertaskGroupResource, c, name, "", metav1.GetOptions{}, &clustertask); err != nil {
 			return err
 		}
 	}
@@ -94,7 +97,7 @@ Show logs for given ClusterTask and associated TaskRun:
 	c.Flags().BoolVarP(&opts.Follow, "follow", "f", false, "stream live logs")
 	c.Flags().BoolVarP(&opts.Timestamps, "timestamps", "t", false, "show logs with timestamp")
 	c.Flags().IntVarP(&opts.Limit, "limit", "", 5, "lists number of TaskRuns")
-
+	c.Deprecated = "ClusterTasks are deprecated, this command will be removed in future releases."
 	return c
 }
 
@@ -139,7 +142,12 @@ func initOpts(opts *options.LogOptions, args []string) error {
 }
 
 func getAllInputs(opts *options.LogOptions) error {
-	cts, err := cthelper.GetAllClusterTaskNames(opts.Params)
+	cs, err := opts.Params.Clients()
+	if err != nil {
+		return err
+	}
+
+	cts, err := clustertask.GetAllClusterTaskNames(clustertaskGroupResource, cs)
 	if err != nil {
 		return err
 	}
@@ -158,15 +166,25 @@ func getAllInputs(opts *options.LogOptions) error {
 }
 
 func askRunName(opts *options.LogOptions) error {
+	cs, err := opts.Params.Clients()
+	if err != nil {
+		return err
+	}
+
 	if opts.Last {
-		return initLastRunName(opts)
+		name, err := initLastRunName(cs, opts.ClusterTaskName, opts.Params.Namespace())
+		if err != nil {
+			return err
+		}
+		opts.TaskrunName = name
+		return nil
 	}
 
 	lOpts := metav1.ListOptions{
 		LabelSelector: fmt.Sprintf("tekton.dev/clusterTask=%s", opts.ClusterTaskName),
 	}
 
-	trs, err := trlist.GetAllTaskRuns(opts.Params, lOpts, opts.Limit)
+	trs, err := taskrunpkg.GetAllTaskRuns(taskrunGroupResource, lOpts, cs, opts.Params.Namespace(), opts.Limit, opts.Params.Time())
 	if err != nil {
 		return err
 	}
@@ -183,15 +201,10 @@ func askRunName(opts *options.LogOptions) error {
 	return opts.Ask(options.ResourceNameTaskRun, trs)
 }
 
-func initLastRunName(opts *options.LogOptions) error {
-	cs, err := opts.Params.Clients()
+func initLastRunName(cs *cli.Clients, name, namespace string) (string, error) {
+	lastrun, err := task.LastRun(cs, name, namespace, "ClusterTask")
 	if err != nil {
-		return err
+		return "", err
 	}
-	lastrun, err := thelper.LastRun(cs, opts.ClusterTaskName, opts.Params.Namespace(), "ClusterTask")
-	if err != nil {
-		return err
-	}
-	opts.TaskrunName = lastrun.Name
-	return nil
+	return lastrun.Name, nil
 }
