@@ -19,13 +19,15 @@ import (
 	"strings"
 
 	"github.com/spf13/cobra"
+	"github.com/tektoncd/cli/pkg/actions"
 	"github.com/tektoncd/cli/pkg/cli"
 	"github.com/tektoncd/cli/pkg/cmd/pipelinerun"
 	"github.com/tektoncd/cli/pkg/flags"
 	"github.com/tektoncd/cli/pkg/formatted"
 	"github.com/tektoncd/cli/pkg/options"
-	"github.com/tektoncd/cli/pkg/pipeline"
-	prhelper "github.com/tektoncd/cli/pkg/pipelinerun"
+	pipelinepkg "github.com/tektoncd/cli/pkg/pipeline"
+	pipelinerunpkg "github.com/tektoncd/cli/pkg/pipelinerun"
+	v1 "github.com/tektoncd/pipeline/pkg/apis/pipeline/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
@@ -36,7 +38,8 @@ func nameArg(args []string, p cli.Params) error {
 			return err
 		}
 		name, ns := args[0], p.Namespace()
-		if _, err = pipeline.Get(c, name, metav1.GetOptions{}, ns); err != nil {
+		var pipeline *v1.Pipeline
+		if err = actions.GetV1(pipelineGroupResource, c, name, ns, metav1.GetOptions{}, &pipeline); err != nil {
 			return err
 		}
 	}
@@ -139,7 +142,12 @@ func getAllInputs(opts *options.LogOptions) error {
 		return err
 	}
 
-	ps, err := pipeline.GetAllPipelineNames(opts.Params)
+	cs, err := opts.Params.Clients()
+	if err != nil {
+		return err
+	}
+
+	ps, err := pipelinepkg.GetAllPipelineNames(pipelineGroupResource, cs, opts.Params.Namespace())
 	if err != nil {
 		return err
 	}
@@ -163,15 +171,25 @@ func askRunName(opts *options.LogOptions) error {
 		return err
 	}
 
+	cs, err := opts.Params.Clients()
+	if err != nil {
+		return err
+	}
+
 	if opts.Last {
-		return initLastRunName(opts)
+		name, err := pipelinepkg.LastRunName(cs, opts.PipelineName, opts.Params.Namespace())
+		if err != nil {
+			return err
+		}
+		opts.PipelineRunName = name
+		return nil
 	}
 
 	lOpts := metav1.ListOptions{
 		LabelSelector: fmt.Sprintf("tekton.dev/pipeline=%s", opts.PipelineName),
 	}
 
-	prs, err := prhelper.GetAllPipelineRuns(opts.Params, lOpts, opts.Limit)
+	prs, err := pipelinerunpkg.GetAllPipelineRuns(pipelineRunGroupResource, lOpts, cs, opts.Params.Namespace(), opts.Limit, opts.Params.Time())
 	if err != nil {
 		return err
 	}
@@ -188,16 +206,3 @@ func askRunName(opts *options.LogOptions) error {
 
 	return opts.Ask(options.ResourceNamePipelineRun, prs)
 }
-
-func initLastRunName(opts *options.LogOptions) error {
-	cs, err := opts.Params.Clients()
-	if err != nil {
-		return err
-	}
-	lastrun, err := pipeline.LastRun(cs, opts.PipelineName, opts.Params.Namespace())
-	if err != nil {
-		return err
-	}
-	opts.PipelineRunName = lastrun.Name
-	return nil
-}
