@@ -21,7 +21,6 @@ import (
 	cb "github.com/tektoncd/cli/pkg/test/builder"
 	testDynamic "github.com/tektoncd/cli/pkg/test/dynamic"
 	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1beta1"
-	pipelinetest "github.com/tektoncd/pipeline/test"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -47,7 +46,7 @@ func TestCreate_ClusterTaskNotExist(t *testing.T) {
 		t.Errorf("unable to create dynamic client: %v", err)
 	}
 
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{ClusterTasks: clustertasks})
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{ClusterTasks: clustertasks})
 	p := &test.Params{Tekton: cs.Pipeline, Kube: cs.Kube, Dynamic: dynamic}
 	p.SetNamespace("default")
 	cs.Pipeline.Resources = cb.APIResourceList(version, []string{"task", "clustertask"})
@@ -83,7 +82,7 @@ func TestCreate(t *testing.T) {
 		t.Errorf("unable to create dynamic client: %v", err)
 	}
 
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{ClusterTasks: ctasks})
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{ClusterTasks: ctasks})
 	p := &test.Params{Tekton: cs.Pipeline, Kube: cs.Kube, Dynamic: dynamic}
 	p.SetNamespace("default")
 	cs.Pipeline.Resources = cb.APIResourceList(version, []string{"task", "clustertask"})
@@ -127,7 +126,7 @@ func TestCreate_InNamespace(t *testing.T) {
 		t.Errorf("unable to create dynamic client: %v", err)
 	}
 
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{ClusterTasks: ctasks, Namespaces: namespaces})
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{ClusterTasks: ctasks, Namespaces: namespaces})
 	p := &test.Params{Tekton: cs.Pipeline, Kube: cs.Kube, Dynamic: dynamic}
 	cs.Pipeline.Resources = cb.APIResourceList(version, []string{"task", "clustertask"})
 
@@ -162,7 +161,7 @@ func TestCreate_WithoutFlag(t *testing.T) {
 		t.Errorf("unable to create dynamic client: %v", err)
 	}
 
-	cs, _ := test.SeedV1beta1TestData(t, pipelinetest.Data{ClusterTasks: clustertasks})
+	cs, _ := test.SeedV1beta1TestData(t, test.Data{ClusterTasks: clustertasks})
 	p := &test.Params{Tekton: cs.Pipeline, Kube: cs.Kube, Dynamic: dynamic}
 	cs.Pipeline.Resources = cb.APIResourceList(version, []string{"task", "clustertask"})
 
