@@ -19,13 +19,15 @@ import (
 	"strings"
 
 	"github.com/spf13/cobra"
+	"github.com/tektoncd/cli/pkg/actions"
 	"github.com/tektoncd/cli/pkg/cli"
 	"github.com/tektoncd/cli/pkg/cmd/taskrun"
 	"github.com/tektoncd/cli/pkg/flags"
 	"github.com/tektoncd/cli/pkg/formatted"
 	"github.com/tektoncd/cli/pkg/options"
-	thelper "github.com/tektoncd/cli/pkg/task"
-	trlist "github.com/tektoncd/cli/pkg/taskrun/list"
+	task "github.com/tektoncd/cli/pkg/task"
+	taskrunpkg "github.com/tektoncd/cli/pkg/taskrun"
+	v1 "github.com/tektoncd/pipeline/pkg/apis/pipeline/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
@@ -36,7 +38,8 @@ func nameArg(args []string, p cli.Params) error {
 			return err
 		}
 		name, ns := args[0], p.Namespace()
-		if _, err = thelper.Get(c, name, metav1.GetOptions{}, ns); err != nil {
+		var task *v1.Task
+		if err = actions.GetV1(taskGroupResource, c, name, ns, metav1.GetOptions{}, &task); err != nil {
 			return err
 		}
 	}
@@ -138,7 +141,11 @@ func initOpts(opts *options.LogOptions, args []string) error {
 }
 
 func getAllInputs(opts *options.LogOptions) error {
-	ts, err := thelper.GetAllTaskNames(opts.Params)
+	cs, err := opts.Params.Clients()
+	if err != nil {
+		return err
+	}
+	ts, err := task.GetAllTaskNames(taskGroupResource, cs, opts.Params.Namespace())
 	if err != nil {
 		return err
 	}
@@ -157,15 +164,25 @@ func getAllInputs(opts *options.LogOptions) error {
 }
 
 func askRunName(opts *options.LogOptions) error {
+	cs, err := opts.Params.Clients()
+	if err != nil {
+		return err
+	}
+
 	if opts.Last {
-		return initLastRunName(opts)
+		name, err := initLastRunName(cs, opts.TaskName, opts.Params.Namespace())
+		if err != nil {
+			return err
+		}
+		opts.TaskrunName = name
+		return nil
 	}
 
 	lOpts := metav1.ListOptions{
 		LabelSelector: fmt.Sprintf("tekton.dev/task=%s", opts.TaskName),
 	}
 
-	trs, err := trlist.GetAllTaskRuns(opts.Params, lOpts, opts.Limit)
+	trs, err := taskrunpkg.GetAllTaskRuns(taskrunGroupResource, lOpts, cs, opts.Params.Namespace(), opts.Limit, opts.Params.Time())
 	if err != nil {
 		return err
 	}
@@ -182,15 +199,10 @@ func askRunName(opts *options.LogOptions) error {
 	return opts.Ask(options.ResourceNameTaskRun, trs)
 }
 
-func initLastRunName(opts *options.LogOptions) error {
-	cs, err := opts.Params.Clients()
+func initLastRunName(cs *cli.Clients, name, namespace string) (string, error) {
+	lastrun, err := task.LastRun(cs, name, namespace, "Task")
 	if err != nil {
-		return err
+		return "", err
 	}
-	lastrun, err := thelper.LastRun(cs, opts.TaskName, opts.Params.Namespace(), "Task")
-	if err != nil {
-		return err
-	}
-	opts.TaskrunName = lastrun.Name
-	return nil
+	return lastrun.Name, nil
 }
