@@ -36,7 +36,6 @@ import (
 	"github.com/tektoncd/cli/test/framework"
 	v1 "github.com/tektoncd/pipeline/pkg/apis/pipeline/v1"
 	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1beta1"
-	"github.com/tektoncd/pipeline/pkg/apis/resource/v1alpha1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
@@ -98,28 +97,6 @@ func GetTaskRunList(c *framework.Clients) *v1.TaskRunList {
 	return taskRunlist
 }
 
-func GetPipelineResource(c *framework.Clients, name string) *v1alpha1.PipelineResource {
-
-	pipelineResource, err := c.PipelineResourceClient.Get(context.Background(), name, metav1.GetOptions{})
-
-	if err != nil {
-		log.Fatalf("Couldn't get expected pipelineResource  %s", err)
-	}
-
-	return pipelineResource
-}
-
-func GetPipelineResourceList(c *framework.Clients) *v1alpha1.PipelineResourceList {
-
-	pipelineResourceList, err := c.PipelineResourceClient.List(context.Background(), metav1.ListOptions{})
-
-	if err != nil {
-		log.Fatalf("Couldn't get expected pipelineResourceList  %s", err)
-	}
-
-	return pipelineResourceList
-}
-
 func GetPipeline(c *framework.Clients, name string) *v1.Pipeline {
 
 	pipeline, err := c.PipelineClient.Get(context.Background(), name, metav1.GetOptions{})
@@ -170,7 +147,7 @@ func GetPipelineRunListWithName(c *framework.Clients, pname string, sortByStartT
 	return pipelineRunList
 }
 
-func GetTaskRunListByLabel(c *framework.Clients, tname string, sortByStartTime bool, label string) *v1.TaskRunList {
+func GetTaskRunListByLabel(c *framework.Clients, sortByStartTime bool, label string) *v1.TaskRunList {
 	opts := metav1.ListOptions{
 		LabelSelector: label,
 	}
@@ -191,12 +168,12 @@ func GetTaskRunListByLabel(c *framework.Clients, tname string, sortByStartTime b
 
 func GetTaskRunListWithTaskName(c *framework.Clients, tname string, sortByStartTime bool) *v1.TaskRunList {
 	label := fmt.Sprintf("tekton.dev/task=%s", tname)
-	return GetTaskRunListByLabel(c, tname, sortByStartTime, label)
+	return GetTaskRunListByLabel(c, sortByStartTime, label)
 }
 
 func GetTaskRunListWithClusterTaskName(c *framework.Clients, ctname string, sortByStartTime bool) *v1.TaskRunList {
 	label := fmt.Sprintf("tekton.dev/clusterTask=%s", ctname)
-	return GetTaskRunListByLabel(c, ctname, sortByStartTime, label)
+	return GetTaskRunListByLabel(c, sortByStartTime, label)
 }
 
 func GetPipelineRunList(c *framework.Clients) *v1.PipelineRunList {
@@ -266,18 +243,6 @@ func ListResourceNamesForJSONPath(obj interface{}) string {
 			return emptyMsg
 		}
 
-		for _, r := range obj.Items {
-			fmt.Fprintf(w, body,
-				r.Name,
-			)
-		}
-		w.Flush()
-		return tmplBytes.String()
-	case *v1alpha1.PipelineResourceList:
-		if len(obj.Items) == 0 {
-			return emptyMsg
-		}
-
 		for _, r := range obj.Items {
 			fmt.Fprintf(w, body,
 				r.Name,
